aboutsummaryrefslogtreecommitdiffstats
path: root/capture.c
diff options
context:
space:
mode:
authorUlf Lamping <ulf.lamping@web.de>2005-04-17 22:44:13 +0000
committerUlf Lamping <ulf.lamping@web.de>2005-04-17 22:44:13 +0000
commit55e312bb4130734243a4b32c4d1eb50e78c6c45e (patch)
tree95e0ea423606186e773e995f0ce1c51e828d71b2 /capture.c
parent5caccdd94ec8d6508699965ed5e1d4b5d807c1c4 (diff)
bugfix: show the right filesize after a live capture finished
svn path=/trunk/; revision=14118
Diffstat (limited to 'capture.c')
-rw-r--r--capture.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/capture.c b/capture.c
index 07b751e9ec..4e21495edf 100644
--- a/capture.c
+++ b/capture.c
@@ -308,7 +308,10 @@ capture_input_closed(capture_options *capture_opts)
}
if(capture_opts->real_time_mode) {
- /* first of all, we are not doing a capture any more */
+ /* first of all, update the file length field */
+ cf_update_f_len(capture_opts->cf);
+
+ /* we are not doing a capture any more */
cf_callback_invoke(cf_cb_live_capture_update_finished, capture_opts->cf);
/* Read what remains of the capture file, and finish the capture.